==> civicccookiecontrol-4.4.4.tar.gz: civicccookiecontrol/src/Form/IAB2Settings.php <==
<?php

namespace Drupal\civiccookiecontrol\Form;

use Drupal\civiccookiecontrol\CCCConfigNames;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Locale\CountryManager;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Symfony\Component\Yaml\Yaml;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The configuration form for cookie control settings.
 */
class IAB2Settings extends ConfigFormBase {

  /**
   * Country manager object.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface|\Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Cache backend object.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cache;

  /**
   * Router builder object.
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  protected $routerBuilder;

  /**
   * IAB2Settings constructor.
   *
   * @param \Drupal\Core\Locale\CountryManager $countryManager
   *   Injected CountyManager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   Injected config factory service.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   Injected cache service.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $routeBuilder
   *   Injected router builder service.
   */
  public function __construct(
        CountryManager $countryManager,
        ConfigFactoryInterface $config,
        CacheBackendInterface $cache,
        RouteBuilderInterface $routeBuilder
    ) {
    $this->countryManager = $countryManager;
    $this->config = $config->getEditable(CCCConfigNames::IAB2);
    $this->cache = $cache;
    $this->routerBuilder = $routeBuilder;
    civiccookiecontrol_check_cookie_categories();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('country_manager'),
          $container->get('config.factory'),
          $container->get('cache.data'),
          $container->get('router.builder')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'iab2_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $configData = $this->config->get();
    foreach ($configData as $key => $configValue) {
      if (strpos($key, 'iab') !== FALSE) {
        if (is_array($form_state->getValue($key)) && array_key_exists('format', $form_state->getValue($key))) {
          $this->config->set($key, $form_state->getValue($key)['value']);
        }
        elseif (strpos($key, 'Text') !== FALSE) {
          if ($form_state->getValue($key) != '') {
            $this->config->set($key, str_replace([
              "\r\n",
              "\n",
              "\r",
            ], '', $form_state->getValue($key)))->save();
          }
        }
        else {
          $this->config->set($key, $form_state->getValue($key))->save();
        }
      }
    }
    $this->cache->delete('civiccookiecontrol_config');
    $this->routerBuilder->rebuild();
    drupal_flush_all_caches();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [CCCConfigNames::IAB2];
  }

  /**
   * Ajax based save of IAB v2.0 option value.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state object.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The ajax response object.
   */
  public function saveIab2Option(array $form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $this->config->set('iabCMP', $form_state->getValue('iabCMP'))->save();
    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['iab'] = [
      '#type' => 'details',
      '#title' => $this->t('IAB V2.0 Settings'),
      '#open' => TRUE,
    ];

    $form['iab']['iabCMP'] = [
      '#type' => 'radios',
      '#title' => $this->t("Enable IAB (TCF V2.2) Support."),
      '#options' => [
        TRUE => $this->t("Yes"),
        FALSE => $this->t('No'),
      ],
      '#ajax' => [
        'callback' => [$this, 'saveIab2Option'],
        'effect' => 'change',
        'progress' => [
          'type' => 'throbber',
          'message' => $this->t('Updating IAB...'),
        ],
      ],
      '#default_value' => $this->config->get('iabCMP') ? 1 : 0,
      '#description' => $this->t("Whether or not Cookie Control supports the IAB's TCF v2.2."),
    ];

    $form['iab']['iabSettings'] = [
      '#type' => 'details',
      '#title' => $this->t('IAB Settings'),
      '#open' => FALSE,
      '#states' => [
      // Action to take.
        'invisible' => [
          ':input[name=iabCMP]' => [
            'value' => 0,
          ],
        ],
      ],
    ];

    $this->loadIabSettings($form);

    $form_state->setCached(FALSE);

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save IAB (TCF v2.0) Configuration'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * Loads IAB 2.0 form elements from the corresponding twig file.
   */
  protected function loadIabSettings(&$form) {
    $iabYamlPath = drupal_get_path('module', 'civiccookiecontrol') . "/src/Form/IAB2FormElements/iab.settings.yml";
    $formItems = Yaml::parse(file_get_contents($iabYamlPath));
    foreach ($formItems as $key => $element) {
      if (array_key_exists('#format', $element) && $element['#format'] == 'full_html') {
        $element['#allowed_formats'] = [$element['#format']];
      }

      if (($element['#default_value'] == $key) &&
          (array_key_exists('boolOptions', $element) && $element['boolOptions'] == 1)) {
        $element['#options'] = [
          TRUE => 'Yes',
          FALSE => 'No',
        ];
        $element['#default_value'] = $this->config->get($key) ? 1 : 0;
      }
      elseif ($element['#default_value'] == $key) {
        $element['#default_value'] = $this->config->get($key);
      }
      unset($element['boolOptions']);
      $form['iab']['iabSettings'][$key] = $element;
    }
  }

}

==> civicccookiecontrol-4.4.8.tar.gz: civicccookiecontrol/src/Form/IAB2Settings.php <==
<?php

namespace Drupal\civiccookiecontrol\Form;

use Drupal\civiccookiecontrol\CCCConfigNames;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Locale\CountryManager;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Symfony\Component\Yaml\Yaml;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The configuration form for cookie control settings.
 */
class IAB2Settings extends ConfigFormBase {

  /**
   * Country manager object.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface|\Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * Cache backend object.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cache;

  /**
   * Router builder object.
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  protected $routerBuilder;

  /**
   * IAB2Settings constructor.
   *
   * @param \Drupal\Core\Locale\CountryManager $countryManager
   *   Injected CountyManager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Injected config factory service.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   Injected cache service.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $routeBuilder
   *   Injected router builder service.
   */
  public function __construct(
        CountryManager $countryManager,
        ConfigFactoryInterface $config_factory,
        CacheBackendInterface $cache,
        RouteBuilderInterface $routeBuilder
    ) {
    parent::__construct($config_factory);
    $this->countryManager = $countryManager;
    $this->cache = $cache;
    $this->routerBuilder = $routeBuilder;
    civiccookiecontrol_check_cookie_categories();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('country_manager'),
          $container->get('config.factory'),
          $container->get('cache.data'),
          $container->get('router.builder')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'iab2_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $configData = $this->config(CCCConfigNames::IAB2)->get();
    foreach ($configData as $key => $configValue) {
      if (strpos($key, 'iab') !== FALSE) {
        if (is_array($form_state->getValue($key)) && array_key_exists('format', $form_state->getValue($key))) {
          $this->config(CCCConfigNames::IAB2)->set($key, $form_state->getValue($key)['value']);
        }
        elseif (strpos($key, 'Text') !== FALSE) {
          if ($form_state->getValue($key) != '') {
            $this->config(CCCConfigNames::IAB2)->set($key, str_replace([
              "\r\n",
              "\n",
              "\r",
            ], '', $form_state->getValue($key)))->save();
          }
        }
        else {
          $this->config(CCCConfigNames::IAB2)->set($key, $form_state->getValue($key))->save();
        }
      }
    }
    $this->cache->delete('civiccookiecontrol_config');
    $this->routerBuilder->rebuild();
    drupal_flush_all_caches();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [CCCConfigNames::IAB2];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['iab'] = [
      '#type' => 'details',
      '#title' => $this->t('IAB V2.0 Settings'),
      '#open' => TRUE,
    ];

    $form['iab']['iabCMP'] = [
      '#type' => 'radios',
      '#title' => $this->t("Enable IAB (TCF V2.2) Support."),
      '#options' => [
        TRUE => $this->t("Yes"),
        FALSE => $this->t('No'),
      ],
      '#default_value' => $this->config(CCCConfigNames::IAB2)->get('iabCMP') ? 1 : 0,
      '#description' => $this->t("Whether or not Cookie Control supports the IAB's TCF v2.2."),
    ];

    $form['iab']['iabSettings'] = [
      '#type' => 'details',
      '#title' => $this->t('IAB Settings'),
      '#open' => FALSE,
      '#states' => [
      // Action to take.
        'invisible' => [
          ':input[name=iabCMP]' => [
            'value' => 0,
          ],
        ],
      ],
    ];

    $this->loadIabSettings($form);

    $form_state->setCached(FALSE);

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save IAB (TCF v2.0) Configuration'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * Loads IAB 2.0 form elements from the corresponding twig file.
   */
  protected function loadIabSettings(&$form) {
    $iabYamlPath = drupal_get_path('module', 'civiccookiecontrol') . "/src/Form/IAB2FormElements/iab.settings.yml";
    $formItems = Yaml::parse(file_get_contents($iabYamlPath));
    foreach ($formItems as $key => $element) {
      if (array_key_exists('#format', $element) && $element['#format'] == 'full_html') {
        $element['#allowed_formats'] = [$element['#format']];
      }

      if (($element['#default_value'] == $key) &&
          (array_key_exists('boolOptions', $element) && $element['boolOptions'] == 1)) {
        $element['#options'] = [
          TRUE => 'Yes',
          FALSE => 'No',
        ];
        $element['#default_value'] = $this->config(CCCConfigNames::IAB2)->get($key) ? 1 : 0;
      }
      elseif ($element['#default_value'] == $key) {
        $element['#default_value'] = $this->config(CCCConfigNames::IAB2)->get($key);
      }
      unset($element['boolOptions']);
      $form['iab']['iabSettings'][$key] = $element;
    }
  }

}
